/*
 * Copyright 2016 Brigham Young University
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

'use strict'

const Promise                   = require('bluebird')
const request                   = require('request-promise')
let   yapiServiceDomainURI      = process.env.YAPI_DOMAIN

exports.URI = function()
{
    if (! yapiServiceDomainURI)
    {
        if ((process.env.ENVIRONMENT) && (process.env.ENVIRONMENT === 'production'))
        {
            yapiServiceDomainURI = 'https://yapi.byu.edu'
        }
        else
        {
            yapiServiceDomainURI = 'https://yapi-dev.byu.edu'
        }
    }
    return yapiServiceDomainURI
}

/**
 * @param userId
 * @param studentId
 * @returns {Promise}
 */
exports.userPolicies = Promise.coroutine( function* (userId, webResourceId)
{
    let requestObject =
    {
        url: exports.URI()+'/accessManager/webResource/'+webResourceId+'/userPolicies/'+userId,
        method: 'GET',
        json: true,
        resolveWithFullResponse: false,
        simple: true,
        encoding: 'utf8',
        headers: {
            'Accept': 'application/json'
        }
    }
    return request(requestObject)
})